import { NullValueRes } from "../../types/common"
import { SlideImage } from "yet-another-react-lightbox"

export interface ILocationDetail {
  id: Number,
  name: String,
  address: String,
  regency_name: String,
  province_name: String,
  region_name: String,  
  google_maps_link: String,
  thumbnail: NullValueRes<"String", String>,
  submitted_by: Number,
  critic_score: Number,
  critic_count: Number,
  user_score: Number,
  user_count: Number
}

export function emptyLocationDetail(): ILocationDetail {
  return {
    id: 0,
    address: '',
    google_maps_link: '',
    thumbnail: { String: '', Valid: false },
    name: '',
    province_name: '',
    regency_name: '',
    region_name: '',
    submitted_by: 0,
    critic_score: 0,
    critic_count: 0,
    user_score: 0,
    user_count: 0,
  }
}

export interface LocationReviewsResponse {
  id: number,
  score: number,
  comments: string,
  user_id: number,
  username: string,
  user_avatar: NullValueRes<"String", string>,
  created_at: string,
  updated_at: string
}

export interface LocationDetailResponse {
  detail: ILocationDetail,
  tags: Array<String>
  users_review: Array<LocationReviewsResponse>,
  critics_review: Array<LocationReviewsResponse>
}


export function EmptyLocationDetailResponse(): LocationDetailResponse {
  return {
    detail: emptyLocationDetail(),
    tags: [],
    critics_review: Array<LocationReviewsResponse>(),
    users_review: Array<LocationReviewsResponse>()
  }
}

export interface LocationImage extends SlideImage {
  id: Number,
  src: string,
  created_at: String,
  uploaded_by: String
}

export interface LocationResponse {
  total_image: Number,
  images: Array<LocationImage>
}

export function emptyLocationResponse(): LocationResponse {
  return {
    total_image: 0,
    images: Array<LocationImage>()
  }
}

export type CurrentUserLocationReviews = {
  id: Number,
  comments: string,
  is_from_critic: boolean,
  is_hided: boolean,
  location_id: Number,
  score: Number,
  submitted_by: Number,
  created_at: NullValueRes<"Time", string>,
  updated_at: NullValueRes<"Time", string>,
}